@@ -186,8 +186,11 @@ struct {
     M("network", Network, Operator),
     M("office", Category, Header),
     M("old_name", OldName, UnresolvedCategory),
-    M("opening_hours", OpeningHours, UnresolvedCategory),
+    M("opening_hours", OpeningHours, OpeningHoursCategory),
     M("operator", OperatorName, Operator),
+    M("operator:email", Email, Contact),
+    M("operator:phone", Phone, Contact),
+    M("operator:website", Website, Contact),
     M("operator:wikipedia", OperatorWikipedia, Operator),
     M("parking:fee", Fee, Parking),
     M("payment:cash", PaymentCash, Payment),
@@ -369,6 +372,7 @@ QString OSMElementInformationModel::categoryLabel(OSMElementInformationModel::Ke
         case UnresolvedCategory:
         case Header:
         case Main:          return {};
+        case OpeningHoursCategory: return i18n("Opening Hours");
         case Contact:       return i18n("Contact");
         case Payment:       return i18n("Payment");
         case Toilets:       return i18n("Toilets");
@@ -406,7 +410,7 @@ QString OSMElementInformationModel::keyName(OSMElementInformationModel::Key key)
         case Diet: return i18n("Diet");
         case Takeaway: return i18n("Takeaway");
         case Socket: return i18n("Socket");
-        case OpeningHours: return i18n("Opening hours");
+        case OpeningHours: return {};
         case Fee: return i18n("Fee");
         case Authentication: return i18n("Authentication");
         case BicycleParking: return i18n("Bicycle parking");
@@ -586,9 +590,9 @@ QVariant OSMElementInformationModel::valueForKey(Info info) const
             return QString::fromUtf8(m_element.tagValue("changing_table", "diaper"));
         case Wikipedia: return wikipediaUrl(m_element.tagValue("wikipedia", "brand:wikipedia", QLocale()));
         case Address: return QVariant::fromValue(OSMAddress(m_element));
-        case Phone: return QString::fromUtf8(m_element.tagValue("contact:phone", "phone", "telephone"));
-        case Email: return QString::fromUtf8(m_element.tagValue("contact:email", "email"));
-        case Website: return QString::fromUtf8(m_element.tagValue("website", "contact:website", "url"));
+        case Phone: return QString::fromUtf8(m_element.tagValue("contact:phone", "phone", "telephone", "operator:phone"));
+        case Email: return QString::fromUtf8(m_element.tagValue("contact:email", "email", "operator:email"));
+        case Website: return QString::fromUtf8(m_element.tagValue("website", "contact:website", "url", "operator:website"));
         case PaymentCash:
         {
             const auto coins = m_element.tagValue("payment:coins");
